@@ -15,10 +15,8 @@ import sys
 from datetime import datetime
 from typing import Any, Dict, List, Type, overload
 
+from boto3.botocore_stubs import ClientError as BotocoreClientError
 from botocore.client import ClientMeta
-from botocore.exceptions import ClientError as Boto3ClientError
-from botocore.paginate import Paginator as Boto3Paginator
-from botocore.waiter import Waiter as Boto3Waiter
 
 from mypy_boto3_docdb.paginator import (
     DescribeCertificatesPaginator,
@@ -88,56 +86,56 @@ __all__ = ("DocDBClient",)
 
 
 class Exceptions:
-    AuthorizationNotFoundFault: Type[Boto3ClientError]
-    CertificateNotFoundFault: Type[Boto3ClientError]
-    ClientError: Type[Boto3ClientError]
-    DBClusterAlreadyExistsFault: Type[Boto3ClientError]
-    DBClusterNotFoundFault: Type[Boto3ClientError]
-    DBClusterParameterGroupNotFoundFault: Type[Boto3ClientError]
-    DBClusterQuotaExceededFault: Type[Boto3ClientError]
-    DBClusterSnapshotAlreadyExistsFault: Type[Boto3ClientError]
-    DBClusterSnapshotNotFoundFault: Type[Boto3ClientError]
-    DBInstanceAlreadyExistsFault: Type[Boto3ClientError]
-    DBInstanceNotFoundFault: Type[Boto3ClientError]
-    DBParameterGroupAlreadyExistsFault: Type[Boto3ClientError]
-    DBParameterGroupNotFoundFault: Type[Boto3ClientError]
-    DBParameterGroupQuotaExceededFault: Type[Boto3ClientError]
-    DBSecurityGroupNotFoundFault: Type[Boto3ClientError]
-    DBSnapshotAlreadyExistsFault: Type[Boto3ClientError]
-    DBSnapshotNotFoundFault: Type[Boto3ClientError]
-    DBSubnetGroupAlreadyExistsFault: Type[Boto3ClientError]
-    DBSubnetGroupDoesNotCoverEnoughAZs: Type[Boto3ClientError]
-    DBSubnetGroupNotFoundFault: Type[Boto3ClientError]
-    DBSubnetGroupQuotaExceededFault: Type[Boto3ClientError]
-    DBSubnetQuotaExceededFault: Type[Boto3ClientError]
-    DBUpgradeDependencyFailureFault: Type[Boto3ClientError]
-    InstanceQuotaExceededFault: Type[Boto3ClientError]
-    InsufficientDBClusterCapacityFault: Type[Boto3ClientError]
-    InsufficientDBInstanceCapacityFault: Type[Boto3ClientError]
-    InsufficientStorageClusterCapacityFault: Type[Boto3ClientError]
-    InvalidDBClusterSnapshotStateFault: Type[Boto3ClientError]
-    InvalidDBClusterStateFault: Type[Boto3ClientError]
-    InvalidDBInstanceStateFault: Type[Boto3ClientError]
-    InvalidDBParameterGroupStateFault: Type[Boto3ClientError]
-    InvalidDBSecurityGroupStateFault: Type[Boto3ClientError]
-    InvalidDBSnapshotStateFault: Type[Boto3ClientError]
-    InvalidDBSubnetGroupStateFault: Type[Boto3ClientError]
-    InvalidDBSubnetStateFault: Type[Boto3ClientError]
-    InvalidRestoreFault: Type[Boto3ClientError]
-    InvalidSubnet: Type[Boto3ClientError]
-    InvalidVPCNetworkStateFault: Type[Boto3ClientError]
-    KMSKeyNotAccessibleFault: Type[Boto3ClientError]
-    ResourceNotFoundFault: Type[Boto3ClientError]
-    SharedSnapshotQuotaExceededFault: Type[Boto3ClientError]
-    SnapshotQuotaExceededFault: Type[Boto3ClientError]
-    StorageQuotaExceededFault: Type[Boto3ClientError]
-    StorageTypeNotSupportedFault: Type[Boto3ClientError]
-    SubnetAlreadyInUse: Type[Boto3ClientError]
+    AuthorizationNotFoundFault: Type[BotocoreClientError]
+    CertificateNotFoundFault: Type[BotocoreClientError]
+    ClientError: Type[BotocoreClientError]
+    DBClusterAlreadyExistsFault: Type[BotocoreClientError]
+    DBClusterNotFoundFault: Type[BotocoreClientError]
+    DBClusterParameterGroupNotFoundFault: Type[BotocoreClientError]
+    DBClusterQuotaExceededFault: Type[BotocoreClientError]
+    DBClusterSnapshotAlreadyExistsFault: Type[BotocoreClientError]
+    DBClusterSnapshotNotFoundFault: Type[BotocoreClientError]
+    DBInstanceAlreadyExistsFault: Type[BotocoreClientError]
+    DBInstanceNotFoundFault: Type[BotocoreClientError]
+    DBParameterGroupAlreadyExistsFault: Type[BotocoreClientError]
+    DBParameterGroupNotFoundFault: Type[BotocoreClientError]
+    DBParameterGroupQuotaExceededFault: Type[BotocoreClientError]
+    DBSecurityGroupNotFoundFault: Type[BotocoreClientError]
+    DBSnapshotAlreadyExistsFault: Type[BotocoreClientError]
+    DBSnapshotNotFoundFault: Type[BotocoreClientError]
+    DBSubnetGroupAlreadyExistsFault: Type[BotocoreClientError]
+    DBSubnetGroupDoesNotCoverEnoughAZs: Type[BotocoreClientError]
+    DBSubnetGroupNotFoundFault: Type[BotocoreClientError]
+    DBSubnetGroupQuotaExceededFault: Type[BotocoreClientError]
+    DBSubnetQuotaExceededFault: Type[BotocoreClientError]
+    DBUpgradeDependencyFailureFault: Type[BotocoreClientError]
+    InstanceQuotaExceededFault: Type[BotocoreClientError]
+    InsufficientDBClusterCapacityFault: Type[BotocoreClientError]
+    InsufficientDBInstanceCapacityFault: Type[BotocoreClientError]
+    InsufficientStorageClusterCapacityFault: Type[BotocoreClientError]
+    InvalidDBClusterSnapshotStateFault: Type[BotocoreClientError]
+    InvalidDBClusterStateFault: Type[BotocoreClientError]
+    InvalidDBInstanceStateFault: Type[BotocoreClientError]
+    InvalidDBParameterGroupStateFault: Type[BotocoreClientError]
+    InvalidDBSecurityGroupStateFault: Type[BotocoreClientError]
+    InvalidDBSnapshotStateFault: Type[BotocoreClientError]
+    InvalidDBSubnetGroupStateFault: Type[BotocoreClientError]
+    InvalidDBSubnetStateFault: Type[BotocoreClientError]
+    InvalidRestoreFault: Type[BotocoreClientError]
+    InvalidSubnet: Type[BotocoreClientError]
+    InvalidVPCNetworkStateFault: Type[BotocoreClientError]
+    KMSKeyNotAccessibleFault: Type[BotocoreClientError]
+    ResourceNotFoundFault: Type[BotocoreClientError]
+    SharedSnapshotQuotaExceededFault: Type[BotocoreClientError]
+    SnapshotQuotaExceededFault: Type[BotocoreClientError]
+    StorageQuotaExceededFault: Type[BotocoreClientError]
+    StorageTypeNotSupportedFault: Type[BotocoreClientError]
+    SubnetAlreadyInUse: Type[BotocoreClientError]
 
 
 class DocDBClient:
     """
-    [DocDB.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/docdb.html#DocDB.Client)
+    [DocDB.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/docdb.html#DocDB.Client)
     """
 
     meta: ClientMeta
@@ -145,19 +143,19 @@ class DocDBClient:
 
     def add_tags_to_resource(self, ResourceName: str, Tags: List["TagTypeDef"]) -> None:
         """
-        [Client.add_tags_to_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/docdb.html#DocDB.Client.add_tags_to_resource)
+        [Client.add_tags_to_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/docdb.html#DocDB.Client.add_tags_to_resource)
         """
 
     def apply_pending_maintenance_action(
         self, ResourceIdentifier: str, ApplyAction: str, OptInType: str
     ) -> ApplyPendingMaintenanceActionResultTypeDef:
         """
-        [Client.apply_pending_maintenance_action documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/docdb.html#DocDB.Client.apply_pending_maintenance_action)
+        [Client.apply_pending_maintenance_action documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/docdb.html#DocDB.Client.apply_pending_maintenance_action)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/docdb.html#DocDB.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/docdb.html#DocDB.Client.can_paginate)
         """
 
     def copy_db_cluster_parameter_group(
@@ -168,7 +166,7 @@ class DocDBClient:
         Tags: List["TagTypeDef"] = None,
     ) -> CopyDBClusterParameterGroupResultTypeDef:
         """
-        [Client.copy_db_cluster_parameter_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/docdb.html#DocDB.Client.copy_db_cluster_parameter_group)
+        [Client.copy_db_cluster_parameter_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/docdb.html#DocDB.Client.copy_db_cluster_parameter_group)
         """
 
     def copy_db_cluster_snapshot(
@@ -182,7 +180,7 @@ class DocDBClient:
         SourceRegion: str = None,
     ) -> CopyDBClusterSnapshotResultTypeDef:
         """
-        [Client.copy_db_cluster_snapshot documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/docdb.html#DocDB.Client.copy_db_cluster_snapshot)
+        [Client.copy_db_cluster_snapshot documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/docdb.html#DocDB.Client.copy_db_cluster_snapshot)
         """
 
     def create_db_cluster(
@@ -207,7 +205,7 @@ class DocDBClient:
         DeletionProtection: bool = None,
     ) -> CreateDBClusterResultTypeDef:
         """
-        [Client.create_db_cluster documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/docdb.html#DocDB.Client.create_db_cluster)
+        [Client.create_db_cluster documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/docdb.html#DocDB.Client.create_db_cluster)
         """
 
     def create_db_cluster_parameter_group(
@@ -218,7 +216,7 @@ class DocDBClient:
         Tags: List["TagTypeDef"] = None,
     ) -> CreateDBClusterParameterGroupResultTypeDef:
         """
-        [Client.create_db_cluster_parameter_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/docdb.html#DocDB.Client.create_db_cluster_parameter_group)
+        [Client.create_db_cluster_parameter_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/docdb.html#DocDB.Client.create_db_cluster_parameter_group)
         """
 
     def create_db_cluster_snapshot(
@@ -228,7 +226,7 @@ class DocDBClient:
         Tags: List["TagTypeDef"] = None,
     ) -> CreateDBClusterSnapshotResultTypeDef:
         """
-        [Client.create_db_cluster_snapshot documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/docdb.html#DocDB.Client.create_db_cluster_snapshot)
+        [Client.create_db_cluster_snapshot documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/docdb.html#DocDB.Client.create_db_cluster_snapshot)
         """
 
     def create_db_instance(
@@ -244,7 +242,7 @@ class DocDBClient:
         PromotionTier: int = None,
     ) -> CreateDBInstanceResultTypeDef:
         """
-        [Client.create_db_instance documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/docdb.html#DocDB.Client.create_db_instance)
+        [Client.create_db_instance documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/docdb.html#DocDB.Client.create_db_instance)
         """
 
     def create_db_subnet_group(
@@ -255,7 +253,7 @@ class DocDBClient:
         Tags: List["TagTypeDef"] = None,
     ) -> CreateDBSubnetGroupResultTypeDef:
         """
-        [Client.create_db_subnet_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/docdb.html#DocDB.Client.create_db_subnet_group)
+        [Client.create_db_subnet_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/docdb.html#DocDB.Client.create_db_subnet_group)
         """
 
     def delete_db_cluster(
@@ -265,29 +263,29 @@ class DocDBClient:
         FinalDBSnapshotIdentifier: str = None,
     ) -> DeleteDBClusterResultTypeDef:
         """
-        [Client.delete_db_cluster documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/docdb.html#DocDB.Client.delete_db_cluster)
+        [Client.delete_db_cluster documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/docdb.html#DocDB.Client.delete_db_cluster)
         """
 
     def delete_db_cluster_parameter_group(self, DBClusterParameterGroupName: str) -> None:
         """
-        [Client.delete_db_cluster_parameter_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/docdb.html#DocDB.Client.delete_db_cluster_parameter_group)
+        [Client.delete_db_cluster_parameter_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/docdb.html#DocDB.Client.delete_db_cluster_parameter_group)
         """
 
     def delete_db_cluster_snapshot(
         self, DBClusterSnapshotIdentifier: str
     ) -> DeleteDBClusterSnapshotResultTypeDef:
         """
-        [Client.delete_db_cluster_snapshot documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/docdb.html#DocDB.Client.delete_db_cluster_snapshot)
+        [Client.delete_db_cluster_snapshot documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/docdb.html#DocDB.Client.delete_db_cluster_snapshot)
         """
 
     def delete_db_instance(self, DBInstanceIdentifier: str) -> DeleteDBInstanceResultTypeDef:
         """
-        [Client.delete_db_instance documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/docdb.html#DocDB.Client.delete_db_instance)
+        [Client.delete_db_instance documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/docdb.html#DocDB.Client.delete_db_instance)
         """
 
     def delete_db_subnet_group(self, DBSubnetGroupName: str) -> None:
         """
-        [Client.delete_db_subnet_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/docdb.html#DocDB.Client.delete_db_subnet_group)
+        [Client.delete_db_subnet_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/docdb.html#DocDB.Client.delete_db_subnet_group)
         """
 
     def describe_certificates(
@@ -298,7 +296,7 @@ class DocDBClient:
         Marker: str = None,
     ) -> CertificateMessageTypeDef:
         """
-        [Client.describe_certificates documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/docdb.html#DocDB.Client.describe_certificates)
+        [Client.describe_certificates documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/docdb.html#DocDB.Client.describe_certificates)
         """
 
     def describe_db_cluster_parameter_groups(
@@ -309,7 +307,7 @@ class DocDBClient:
         Marker: str = None,
     ) -> DBClusterParameterGroupsMessageTypeDef:
         """
-        [Client.describe_db_cluster_parameter_groups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/docdb.html#DocDB.Client.describe_db_cluster_parameter_groups)
+        [Client.describe_db_cluster_parameter_groups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/docdb.html#DocDB.Client.describe_db_cluster_parameter_groups)
         """
 
     def describe_db_cluster_parameters(
@@ -321,14 +319,14 @@ class DocDBClient:
         Marker: str = None,
     ) -> DBClusterParameterGroupDetailsTypeDef:
         """
-        [Client.describe_db_cluster_parameters documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/docdb.html#DocDB.Client.describe_db_cluster_parameters)
+        [Client.describe_db_cluster_parameters documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/docdb.html#DocDB.Client.describe_db_cluster_parameters)
         """
 
     def describe_db_cluster_snapshot_attributes(
         self, DBClusterSnapshotIdentifier: str
     ) -> DescribeDBClusterSnapshotAttributesResultTypeDef:
         """
-        [Client.describe_db_cluster_snapshot_attributes documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/docdb.html#DocDB.Client.describe_db_cluster_snapshot_attributes)
+        [Client.describe_db_cluster_snapshot_attributes documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/docdb.html#DocDB.Client.describe_db_cluster_snapshot_attributes)
         """
 
     def describe_db_cluster_snapshots(
@@ -343,7 +341,7 @@ class DocDBClient:
         IncludePublic: bool = None,
     ) -> DBClusterSnapshotMessageTypeDef:
         """
-        [Client.describe_db_cluster_snapshots documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/docdb.html#DocDB.Client.describe_db_cluster_snapshots)
+        [Client.describe_db_cluster_snapshots documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/docdb.html#DocDB.Client.describe_db_cluster_snapshots)
         """
 
     def describe_db_clusters(
@@ -354,7 +352,7 @@ class DocDBClient:
         Marker: str = None,
     ) -> DBClusterMessageTypeDef:
         """
-        [Client.describe_db_clusters documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/docdb.html#DocDB.Client.describe_db_clusters)
+        [Client.describe_db_clusters documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/docdb.html#DocDB.Client.describe_db_clusters)
         """
 
     def describe_db_engine_versions(
@@ -370,7 +368,7 @@ class DocDBClient:
         ListSupportedTimezones: bool = None,
     ) -> DBEngineVersionMessageTypeDef:
         """
-        [Client.describe_db_engine_versions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/docdb.html#DocDB.Client.describe_db_engine_versions)
+        [Client.describe_db_engine_versions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/docdb.html#DocDB.Client.describe_db_engine_versions)
         """
 
     def describe_db_instances(
@@ -381,7 +379,7 @@ class DocDBClient:
         Marker: str = None,
     ) -> DBInstanceMessageTypeDef:
         """
-        [Client.describe_db_instances documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/docdb.html#DocDB.Client.describe_db_instances)
+        [Client.describe_db_instances documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/docdb.html#DocDB.Client.describe_db_instances)
         """
 
     def describe_db_subnet_groups(
@@ -392,7 +390,7 @@ class DocDBClient:
         Marker: str = None,
     ) -> DBSubnetGroupMessageTypeDef:
         """
-        [Client.describe_db_subnet_groups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/docdb.html#DocDB.Client.describe_db_subnet_groups)
+        [Client.describe_db_subnet_groups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/docdb.html#DocDB.Client.describe_db_subnet_groups)
         """
 
     def describe_engine_default_cluster_parameters(
@@ -403,14 +401,14 @@ class DocDBClient:
         Marker: str = None,
     ) -> DescribeEngineDefaultClusterParametersResultTypeDef:
         """
-        [Client.describe_engine_default_cluster_parameters documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/docdb.html#DocDB.Client.describe_engine_default_cluster_parameters)
+        [Client.describe_engine_default_cluster_parameters documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/docdb.html#DocDB.Client.describe_engine_default_cluster_parameters)
         """
 
     def describe_event_categories(
         self, SourceType: str = None, Filters: List[FilterTypeDef] = None
     ) -> EventCategoriesMessageTypeDef:
         """
-        [Client.describe_event_categories documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/docdb.html#DocDB.Client.describe_event_categories)
+        [Client.describe_event_categories documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/docdb.html#DocDB.Client.describe_event_categories)
         """
 
     def describe_events(
@@ -433,7 +431,7 @@ class DocDBClient:
         Marker: str = None,
     ) -> EventsMessageTypeDef:
         """
-        [Client.describe_events documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/docdb.html#DocDB.Client.describe_events)
+        [Client.describe_events documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/docdb.html#DocDB.Client.describe_events)
         """
 
     def describe_orderable_db_instance_options(
@@ -448,7 +446,7 @@ class DocDBClient:
         Marker: str = None,
     ) -> OrderableDBInstanceOptionsMessageTypeDef:
         """
-        [Client.describe_orderable_db_instance_options documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/docdb.html#DocDB.Client.describe_orderable_db_instance_options)
+        [Client.describe_orderable_db_instance_options documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/docdb.html#DocDB.Client.describe_orderable_db_instance_options)
         """
 
     def describe_pending_maintenance_actions(
@@ -459,14 +457,14 @@ class DocDBClient:
         MaxRecords: int = None,
     ) -> PendingMaintenanceActionsMessageTypeDef:
         """
-        [Client.describe_pending_maintenance_actions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/docdb.html#DocDB.Client.describe_pending_maintenance_actions)
+        [Client.describe_pending_maintenance_actions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/docdb.html#DocDB.Client.describe_pending_maintenance_actions)
         """
 
     def failover_db_cluster(
         self, DBClusterIdentifier: str = None, TargetDBInstanceIdentifier: str = None
     ) -> FailoverDBClusterResultTypeDef:
         """
-        [Client.failover_db_cluster documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/docdb.html#DocDB.Client.failover_db_cluster)
+        [Client.failover_db_cluster documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/docdb.html#DocDB.Client.failover_db_cluster)
         """
 
     def generate_presigned_url(
@@ -477,14 +475,14 @@ class DocDBClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/docdb.html#DocDB.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/docdb.html#DocDB.Client.generate_presigned_url)
         """
 
     def list_tags_for_resource(
         self, ResourceName: str, Filters: List[FilterTypeDef] = None
     ) -> TagListMessageTypeDef:
         """
-        [Client.list_tags_for_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/docdb.html#DocDB.Client.list_tags_for_resource)
+        [Client.list_tags_for_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/docdb.html#DocDB.Client.list_tags_for_resource)
         """
 
     def modify_db_cluster(
@@ -504,14 +502,14 @@ class DocDBClient:
         DeletionProtection: bool = None,
     ) -> ModifyDBClusterResultTypeDef:
         """
-        [Client.modify_db_cluster documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/docdb.html#DocDB.Client.modify_db_cluster)
+        [Client.modify_db_cluster documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/docdb.html#DocDB.Client.modify_db_cluster)
         """
 
     def modify_db_cluster_parameter_group(
         self, DBClusterParameterGroupName: str, Parameters: List["ParameterTypeDef"]
     ) -> DBClusterParameterGroupNameMessageTypeDef:
         """
-        [Client.modify_db_cluster_parameter_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/docdb.html#DocDB.Client.modify_db_cluster_parameter_group)
+        [Client.modify_db_cluster_parameter_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/docdb.html#DocDB.Client.modify_db_cluster_parameter_group)
         """
 
     def modify_db_cluster_snapshot_attribute(
@@ -522,7 +520,7 @@ class DocDBClient:
         ValuesToRemove: List[str] = None,
     ) -> ModifyDBClusterSnapshotAttributeResultTypeDef:
         """
-        [Client.modify_db_cluster_snapshot_attribute documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/docdb.html#DocDB.Client.modify_db_cluster_snapshot_attribute)
+        [Client.modify_db_cluster_snapshot_attribute documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/docdb.html#DocDB.Client.modify_db_cluster_snapshot_attribute)
         """
 
     def modify_db_instance(
@@ -537,26 +535,26 @@ class DocDBClient:
         PromotionTier: int = None,
     ) -> ModifyDBInstanceResultTypeDef:
         """
-        [Client.modify_db_instance documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/docdb.html#DocDB.Client.modify_db_instance)
+        [Client.modify_db_instance documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/docdb.html#DocDB.Client.modify_db_instance)
         """
 
     def modify_db_subnet_group(
         self, DBSubnetGroupName: str, SubnetIds: List[str], DBSubnetGroupDescription: str = None
     ) -> ModifyDBSubnetGroupResultTypeDef:
         """
-        [Client.modify_db_subnet_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/docdb.html#DocDB.Client.modify_db_subnet_group)
+        [Client.modify_db_subnet_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/docdb.html#DocDB.Client.modify_db_subnet_group)
         """
 
     def reboot_db_instance(
         self, DBInstanceIdentifier: str, ForceFailover: bool = None
     ) -> RebootDBInstanceResultTypeDef:
         """
-        [Client.reboot_db_instance documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/docdb.html#DocDB.Client.reboot_db_instance)
+        [Client.reboot_db_instance documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/docdb.html#DocDB.Client.reboot_db_instance)
         """
 
     def remove_tags_from_resource(self, ResourceName: str, TagKeys: List[str]) -> None:
         """
-        [Client.remove_tags_from_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/docdb.html#DocDB.Client.remove_tags_from_resource)
+        [Client.remove_tags_from_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/docdb.html#DocDB.Client.remove_tags_from_resource)
         """
 
     def reset_db_cluster_parameter_group(
@@ -566,7 +564,7 @@ class DocDBClient:
         Parameters: List["ParameterTypeDef"] = None,
     ) -> DBClusterParameterGroupNameMessageTypeDef:
         """
-        [Client.reset_db_cluster_parameter_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/docdb.html#DocDB.Client.reset_db_cluster_parameter_group)
+        [Client.reset_db_cluster_parameter_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/docdb.html#DocDB.Client.reset_db_cluster_parameter_group)
         """
 
     def restore_db_cluster_from_snapshot(
@@ -585,7 +583,7 @@ class DocDBClient:
         DeletionProtection: bool = None,
     ) -> RestoreDBClusterFromSnapshotResultTypeDef:
         """
-        [Client.restore_db_cluster_from_snapshot documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/docdb.html#DocDB.Client.restore_db_cluster_from_snapshot)
+        [Client.restore_db_cluster_from_snapshot documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/docdb.html#DocDB.Client.restore_db_cluster_from_snapshot)
         """
 
     def restore_db_cluster_to_point_in_time(
@@ -603,17 +601,17 @@ class DocDBClient:
         DeletionProtection: bool = None,
     ) -> RestoreDBClusterToPointInTimeResultTypeDef:
         """
-        [Client.restore_db_cluster_to_point_in_time documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/docdb.html#DocDB.Client.restore_db_cluster_to_point_in_time)
+        [Client.restore_db_cluster_to_point_in_time documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/docdb.html#DocDB.Client.restore_db_cluster_to_point_in_time)
         """
 
     def start_db_cluster(self, DBClusterIdentifier: str) -> StartDBClusterResultTypeDef:
         """
-        [Client.start_db_cluster documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/docdb.html#DocDB.Client.start_db_cluster)
+        [Client.start_db_cluster documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/docdb.html#DocDB.Client.start_db_cluster)
         """
 
     def stop_db_cluster(self, DBClusterIdentifier: str) -> StopDBClusterResultTypeDef:
         """
-        [Client.stop_db_cluster documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/docdb.html#DocDB.Client.stop_db_cluster)
+        [Client.stop_db_cluster documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/docdb.html#DocDB.Client.stop_db_cluster)
         """
 
     @overload
@@ -621,7 +619,7 @@ class DocDBClient:
         self, operation_name: Literal["describe_certificates"]
     ) -> DescribeCertificatesPaginator:
         """
-        [Paginator.DescribeCertificates documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/docdb.html#DocDB.Paginator.DescribeCertificates)
+        [Paginator.DescribeCertificates documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/docdb.html#DocDB.Paginator.DescribeCertificates)
         """
 
     @overload
@@ -629,7 +627,7 @@ class DocDBClient:
         self, operation_name: Literal["describe_db_cluster_parameter_groups"]
     ) -> DescribeDBClusterParameterGroupsPaginator:
         """
-        [Paginator.DescribeDBClusterParameterGroups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/docdb.html#DocDB.Paginator.DescribeDBClusterParameterGroups)
+        [Paginator.DescribeDBClusterParameterGroups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/docdb.html#DocDB.Paginator.DescribeDBClusterParameterGroups)
         """
 
     @overload
@@ -637,7 +635,7 @@ class DocDBClient:
         self, operation_name: Literal["describe_db_cluster_parameters"]
     ) -> DescribeDBClusterParametersPaginator:
         """
-        [Paginator.DescribeDBClusterParameters documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/docdb.html#DocDB.Paginator.DescribeDBClusterParameters)
+        [Paginator.DescribeDBClusterParameters documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/docdb.html#DocDB.Paginator.DescribeDBClusterParameters)
         """
 
     @overload
@@ -645,7 +643,7 @@ class DocDBClient:
         self, operation_name: Literal["describe_db_cluster_snapshots"]
     ) -> DescribeDBClusterSnapshotsPaginator:
         """
-        [Paginator.DescribeDBClusterSnapshots documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/docdb.html#DocDB.Paginator.DescribeDBClusterSnapshots)
+        [Paginator.DescribeDBClusterSnapshots documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/docdb.html#DocDB.Paginator.DescribeDBClusterSnapshots)
         """
 
     @overload
@@ -653,7 +651,7 @@ class DocDBClient:
         self, operation_name: Literal["describe_db_clusters"]
     ) -> DescribeDBClustersPaginator:
         """
-        [Paginator.DescribeDBClusters documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/docdb.html#DocDB.Paginator.DescribeDBClusters)
+        [Paginator.DescribeDBClusters documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/docdb.html#DocDB.Paginator.DescribeDBClusters)
         """
 
     @overload
@@ -661,7 +659,7 @@ class DocDBClient:
         self, operation_name: Literal["describe_db_engine_versions"]
     ) -> DescribeDBEngineVersionsPaginator:
         """
-        [Paginator.DescribeDBEngineVersions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/docdb.html#DocDB.Paginator.DescribeDBEngineVersions)
+        [Paginator.DescribeDBEngineVersions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/docdb.html#DocDB.Paginator.DescribeDBEngineVersions)
         """
 
     @overload
@@ -669,7 +667,7 @@ class DocDBClient:
         self, operation_name: Literal["describe_db_instances"]
     ) -> DescribeDBInstancesPaginator:
         """
-        [Paginator.DescribeDBInstances documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/docdb.html#DocDB.Paginator.DescribeDBInstances)
+        [Paginator.DescribeDBInstances documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/docdb.html#DocDB.Paginator.DescribeDBInstances)
         """
 
     @overload
@@ -677,13 +675,13 @@ class DocDBClient:
         self, operation_name: Literal["describe_db_subnet_groups"]
     ) -> DescribeDBSubnetGroupsPaginator:
         """
-        [Paginator.DescribeDBSubnetGroups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/docdb.html#DocDB.Paginator.DescribeDBSubnetGroups)
+        [Paginator.DescribeDBSubnetGroups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/docdb.html#DocDB.Paginator.DescribeDBSubnetGroups)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["describe_events"]) -> DescribeEventsPaginator:
         """
-        [Paginator.DescribeEvents documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/docdb.html#DocDB.Paginator.DescribeEvents)
+        [Paginator.DescribeEvents documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/docdb.html#DocDB.Paginator.DescribeEvents)
         """
 
     @overload
@@ -691,7 +689,7 @@ class DocDBClient:
         self, operation_name: Literal["describe_orderable_db_instance_options"]
     ) -> DescribeOrderableDBInstanceOptionsPaginator:
         """
-        [Paginator.DescribeOrderableDBInstanceOptions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/docdb.html#DocDB.Paginator.DescribeOrderableDBInstanceOptions)
+        [Paginator.DescribeOrderableDBInstanceOptions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/docdb.html#DocDB.Paginator.DescribeOrderableDBInstanceOptions)
         """
 
     @overload
@@ -699,25 +697,19 @@ class DocDBClient:
         self, operation_name: Literal["describe_pending_maintenance_actions"]
     ) -> DescribePendingMaintenanceActionsPaginator:
         """
-        [Paginator.DescribePendingMaintenanceActions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/docdb.html#DocDB.Paginator.DescribePendingMaintenanceActions)
+        [Paginator.DescribePendingMaintenanceActions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/docdb.html#DocDB.Paginator.DescribePendingMaintenanceActions)
         """
 
-    def get_paginator(self, operation_name: str) -> Boto3Paginator:
-        pass
-
     @overload
     def get_waiter(
         self, waiter_name: Literal["db_instance_available"]
     ) -> DBInstanceAvailableWaiter:
         """
-        [Waiter.DBInstanceAvailable documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/docdb.html#DocDB.Waiter.DBInstanceAvailable)
+        [Waiter.DBInstanceAvailable documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/docdb.html#DocDB.Waiter.DBInstanceAvailable)
         """
 
     @overload
     def get_waiter(self, waiter_name: Literal["db_instance_deleted"]) -> DBInstanceDeletedWaiter:
         """
-        [Waiter.DBInstanceDeleted documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/docdb.html#DocDB.Waiter.DBInstanceDeleted)
+        [Waiter.DBInstanceDeleted documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/docdb.html#DocDB.Waiter.DBInstanceDeleted)
         """
-
-    def get_waiter(self, waiter_name: str) -> Boto3Waiter:
-        pass
